@@ -2,7 +2,7 @@
 package Net::DigitalNZ;
 #Based heavily on Net::Twitter
 
-$VERSION = "0.14";
+$VERSION = "0.15";
 use 5.005;
 use strict;
 
@@ -132,24 +132,23 @@ sub search {
 
 1;
 __END__
-
 =head1 NAME
 
 Net::DigitalNZ - Perl interface to digitalnz.org 's open data api.
 
 =head1 DESCRIPTION
-      
-  The metadata available through DigitalNZ comes from content providers across the New Zealand cultural and heritage, broadcasting, education, and government sectors; as well as local community sources and individuals.
 
-  You will need to obtain your own API key from http://digitalnz.org
-      
+The metadata available through DigitalNZ comes from content providers across the New Zealand cultural and heritage, broadcasting, education, and government sectors; as well as local community sources and individuals.
+
+You will need to obtain your own API key from http://digitalnz.org
+
 =head1 SYNOPSIS
-      
-      use Net::DigitalNZ;
-      my $query = 'Waitangi';
-      my $api_key = 'get your own api key';
-      my $searcher = Net::DigitalNZ->new(api_key => $api_key);
-      my $results = $searcher->search($query);
+
+     use Net::DigitalNZ;
+     my $query = 'Waitangi';
+     my $api_key = 'get your own api key';
+     my $searcher = Net::DigitalNZ->new(api_key => $api_key);
+     my $results = $searcher->search($query);
 
 =head1 METHODS
 
@@ -157,68 +156,135 @@ Net::DigitalNZ - Perl interface to digitalnz.org 's open data api.
 
 The search records API call is passed a search query and returns a corresponding result set
 
-      #simple query
-      my $results = $searcher->search($query);
-      
-      #more complicated query
-      my $results = $searcher->search($query, {key => value});
+     # simple query
+     my $results = $searcher->search($query);
 
-  params
-    * num_results - the number of results the user wishes returned
-    * start - the offset from which the result list should start
-    * sort - the field upon which results are sorted. If sort_field isn't specified the results are sorted by relevance. The sort_field must be one of: category, content_provider, date, syndication_date, title
-    * direction - the direction in which the results are sorted. Can only be used in conjunction with the sort field and must be either asc or desc. If not specified, sort_direction defaults to asc
-    * facets - a list of facet fields to include in the output. See the note on facets below for more information.
-    * facet_num_results - the number of facet results to include. Only used if the facets parameter is specified, and defaults to 10.
-    * facet_start - the offset from which the facet value list should start. Only used if the facets parameter is specified, and defaults to 0.
+     # more complicated query
+     my $results = $searcher->search($query, {key => value});
 
-=head2 Example
-      
-      use Net::DigitalNZ;
-      
-      my $query = 'Waitangi';
-      
-      my $api_key = 'get your own api key from http://digitalnz.org';
-      
-      my $searcher = Net::DigitalNZ->new(api_key => $api_key);
+=head3 Parameters
+
+=over 4
+
+=item num_results
+
+the number of results the user wishes returned
+
+=item start
+
+the offset from which the result list should start
+
+=item sort
+
+the field upon which results are sorted. If sort_field isn't specified the results are sorted by relevance. The sort_field must be one of: category, content_provider, date, syndication_date, title
+
+=item direction
+
+the direction in which the results are sorted. Can only be used in conjunction with the sort field and must be either asc or desc. If not specified, sort_direction defaults to asc
+
+=item facets
+
+a list of facet fields to include in the output. See the note on facets below for more information.
+
+=item facet_num_results
+
+the number of facet results to include. Only used if the facets parameter is specified, and defaults to 10.
+
+=item facet_start
+
+the offset from which the facet value list should start. Only used if the facets parameter is specified, and defaults to 0.
+
+=back
+
+=head3 Example
+
+     use Net::DigitalNZ;
+
+     my $query = 'Waitangi';
+     my $api_key = 'get your own api key from http://digitalnz.org';
+
+     my $searcher = Net::DigitalNZ->new(api_key => $api_key);
+     my $results = $searcher->search($query, {
+                          start=>10,
+                          num_results => 2}
+                   );
+
+     print $results->{result_count} . " items found\n";
+
+     foreach my $r (@{ $results->{results} } ) {
+          print $r->{id} . ': '. $r->{title} ."\n";
+     }
 
-      my $results = $searcher->search($query, {start=>10, num_results => 2});
-      print $results->{result_count} . " items found\n";
-      foreach my $r (@{ $results->{results} } ) {
-        print $r->{id} . ': '. $r->{title} ."\n";
-      }      
-      
 More info at http://www.digitalnz.org/developer/api-docs/search-records
-      
+
 =head2 Response elements
-      
+
 The search results will return the following elements:
-      
-num_results_requested
-  the value of the num_results parameter sent to the API method
-      
-result_count
-  the total number of results matching this search
 
-start
-  the value of the start parameter sent to the API method
-      
-results
-  the search results data. The results element will contain 0 or more result elements, each containing the following elements:
+=over 4
 
-  * category - a string containing one or more category names separated by a comma (e.g. Images, Web pages)      
-  * content_provider - the institution holding the content to which the record refers      
-  * date - a date associated with the record (e.g. 1996-01-01T00:00:00.000Z). This field may be empty
-  * description - text describing the record
-  * display_url - the url for the content on the content provider's website
-  * id the internal DigitalNZ identifier (used by the Get Metadata API)
-  * metadata-url - the url to the DigitalNZ API method that will return the full metadata for the record
-  * source-url - the url that will redirect users directly to the content_url
-  * thumbnail-url - the url of for a thumbnail image of the content to which the record refers. This field may be empty.
-  * facets - the facet result data (if requested). The facets element will contain one facet-field element corresponding to each facet requested. Each facet-field element contains a sorted list of value elements that are made up of a name and num-results element. See the note below for more information on facets.
+=item num_results_requested
+
+the value of the num_results parameter sent to the API method
+
+=item result_count
+
+the total number of results matching this search
+
+=item start
+
+the value of the start parameter sent to the API method
+
+=item results
+
+the search results data. The results element will contain 0 or more result elements, each containing the following elements:
+
+=over 4
+
+=item category
+
+a string containing one or more category names separated by a comma (e.g. Images, Web pages)
+
+=item content_provider
+
+the institution holding the content to which the record refers
+
+=item date
+
+a date associated with the record (e.g. 1996-01-01T00:00:00.000Z). This field may be empty
+
+=item description
+
+text describing the record
+
+=item display_url
+
+the url for the content on the content provider's website
+
+=item id
+
+the internal DigitalNZ identifier (used by the Get Metadata API)
+
+=item metadata-url
+
+the url to the DigitalNZ API method that will return the full metadata for the record
+
+=item source-url
+
+the url that will redirect users directly to the content_url
+
+=item thumbnail-url
+
+the url of for a thumbnail image of the content to which the record refers. This field may be empty.
+
+=back
+
+=item facets
+
+the facet result data (if requested). The facets element will contain one facet-field element corresponding to each facet requested. Each facet-field element contains a sorted list of value elements that are made up of a name and num-results element. See the note below for more information on facets.
+
+=back
 
-      
-    
 =head1 LICENCE AND COPYRIGHT
 
 This module is free software; you can redistribute it and/or
@@ -227,11 +293,11 @@ modify it under the same terms as Perl itself. See L<perlartistic>.
 =head1 VERSION CONTROL
 
 http://github.com/Br3nda/perl-net-digitalnz/tree/master
-      
+
 =head1 AUTHOR
 
 Brenda Wallace <brenda@wallace.net.nz> http://br3nda.com
-      
+
 Based heavily on L<Net::Twitter> by Chris Thompson
 
 =head1 DISCLAIMER OF WARRANTY
@@ -256,5 +322,5 @@ RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
 FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
 SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGES.
-                                                                                                                    
+
 =cut
